import{o as d,z as u,b as s,A as m,l as o,aA as l,L as h,M as p}from"./_plugin-vue_export-helper-DUzLnECA.js";import{R as f}from"./RestrictedAuth-DRoTWg7u.js";import{g as a}from"./helpers-DzjFIx78.js";import"./pow-DUr-T9XX.js";const w={__name:"RestrictedForward",setup(_){const n=o(()=>l()),r=o(()=>{const e=document.documentElement.getAttribute("data-mode");return e==="reauth"?"reauth":e==="forbidden"?"forbidden":"login"});function i(){location.reload()}function c(){const t=n.value||"/auth/";window.location.pathname!==t&&history.replaceState(null,"",t),window.location.href=t}return d(()=>{window.addEventListener("keydown",t=>{t.key==="Escape"&&a()})}),(t,e)=>(s(),u(f,{mode:r.value,onAuthenticated:i,onBack:m(a),onHome:c},null,8,["mode","onBack"]))}};h(w).mount("#app");p();
